pub struct DrawableShape { /* private fields */ }Expand description
A shape with associated drawing properties for canvas rendering.
Combines geometric shape information with visual styling properties to create drawable annotations.
Typically this is constructed during the process of tracking and sent to the client for rendering.
Implementations
Sourceimpl DrawableShape
impl DrawableShape
Sourcepub fn from_shape(
shape: &Shape,
stroke_style: &StrokeStyle,
line_width: f32,
) -> Self
pub fn from_shape( shape: &Shape, stroke_style: &StrokeStyle, line_width: f32, ) -> Self
Creates a new drawable shape from a geometric shape and styling properties.